@@ -101,22 +101,6 @@ adwaita_engine_render_arrow (GtkThemingEngine *engine,
 
   state = gtk_theming_engine_get_state (engine);
   gtk_theming_engine_get_color (engine, state, &color);
-
-  if (gtk_theming_engine_has_class (engine, GTK_STYLE_CLASS_MENUITEM) &&
-      !(state & GTK_STATE_FLAG_INSENSITIVE) && !(state & GTK_STATE_FLAG_PRELIGHT))
-    {
-      GdkRGBA *arrow_color;
-
-      gtk_theming_engine_get (engine, state,
-                              "-adwaita-menuitem-arrow-color", &arrow_color,
-                              NULL);
-
-      if (arrow_color != NULL)
-        color = *arrow_color;
-
-      gdk_rgba_free (arrow_color);
-    }
-
   gdk_cairo_set_source_rgba (cr, &color);
   cairo_stroke (cr);
 
@@ -131,8 +115,7 @@ adwaita_engine_render_focus (GtkThemingEngine *engine,
                              gdouble           width,
                              gdouble           height)
 {
-  GdkRGBA *fill_color, *border_color = NULL;
-  cairo_pattern_t *pattern = NULL;
+  GdkRGBA *border_color = NULL;
   GtkStateFlags state;
   gint line_width, focus_pad;
   gint border_radius;
@@ -144,9 +127,7 @@ adwaita_engine_render_focus (GtkThemingEngine *engine,
   state = gtk_theming_engine_get_state (engine);
   gtk_theming_engine_get (engine, state,
                           "-adwaita-focus-border-color", &border_color,
-                          "-adwaita-focus-fill-color", &fill_color,
                           "-adwaita-focus-border-radius", &border_radius,
-                          "-adwaita-focus-border-gradient", &pattern,
                           "-adwaita-focus-border-dashes", &use_dashes,
                           NULL);
 
@@ -189,64 +170,17 @@ adwaita_engine_render_focus (GtkThemingEngine *engine,
                                   width - 1, height - 1,
                                   SIDE_ALL, GTK_JUNCTION_NONE);
 
-  /* if we have a fill color, draw the fill */
-  if (fill_color != NULL)
-    {
-      gdk_cairo_set_source_rgba (cr, fill_color);
-      cairo_fill_preserve (cr);
-    }
-
   if (use_dashes)
     cairo_set_dash (cr, dashes, 1, 0.0);
 
-  /* if we have a gradient, draw the gradient, otherwise
-   * draw the line if we have a color for it.
-   */
-  if (pattern != NULL)
-    {
-      style_pattern_set_matrix (pattern, width, height, FALSE);
-      cairo_set_source (cr, pattern);
-    }
-  else if (border_color != NULL)
-    {
-      gdk_cairo_set_source_rgba (cr, border_color);
-    }
+  if (border_color != NULL)
+    gdk_cairo_set_source_rgba (cr, border_color);
 
   cairo_stroke (cr);
   cairo_restore (cr);
 
-  if (pattern != NULL)
-    cairo_pattern_destroy (pattern);
-
   if (border_color != NULL)
     gdk_rgba_free (border_color);
-
-  if (fill_color != NULL)
-    gdk_rgba_free (fill_color);
-}
-
-static void
-adwaita_engine_render_check (GtkThemingEngine *engine,
-                             cairo_t          *cr,
-                             gdouble           x,
-                             gdouble           y,
-                             gdouble           width,
-                             gdouble           height)
-{
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_background
-    (engine, cr, x, y, width, height);
-}
-
-static void
-adwaita_engine_render_option (GtkThemingEngine *engine,
-                              cairo_t          *cr,
-                              gdouble           x,
-                              gdouble           y,
-                              gdouble           width,
-                              gdouble           height)
-{
-  GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_background
-      (engine, cr, x, y, width, height);
 }
 
 static void
@@ -336,6 +270,9 @@ render_notebook_extension (GtkThemingEngine *engine,
   width -= 1.0;
   draw_tab_shape_active (cr, tab_curvature, 0, 0, width, height);
 
+  gdk_cairo_set_source_rgba (cr, &background_color);
+  cairo_fill_preserve (cr);
+
   if (background_pattern != NULL)
     {
       cairo_matrix_init_scale (&matrix,
@@ -343,13 +280,9 @@ render_notebook_extension (GtkThemingEngine *engine,
                                1. / height);
       cairo_pattern_set_matrix (background_pattern, &matrix);
       cairo_set_source (cr, background_pattern);
-    }
-  else
-    {
-      gdk_cairo_set_source_rgba (cr, &background_color);
-    }
 
-  cairo_fill (cr);
+      cairo_fill (cr);
+    }
 
   if (state & GTK_STATE_FLAG_ACTIVE)
     {
@@ -362,8 +295,9 @@ render_notebook_extension (GtkThemingEngine *engine,
 
   if (state & GTK_STATE_FLAG_ACTIVE)
     {
-      style_pattern_set_matrix (pattern, width, height - 6.0, FALSE);
+      cairo_scale (cr, width, height - 6.0);
       cairo_set_source (cr, pattern);
+      cairo_scale (cr, 1.0 / width, 1.0 / (height - 6.0));
     }
   else
     {
@@ -593,9 +527,12 @@ adwaita_engine_render_activity (GtkThemingEngine *engine,
 
       if (pattern != NULL)
         {
-          style_pattern_set_matrix (pattern, 20, 20, TRUE);
-          cairo_rectangle (cr, x, y, width, height);
+          cairo_pattern_set_extend (pattern, CAIRO_EXTEND_REPEAT);
+          cairo_scale (cr, 20, 20);
           cairo_set_source (cr, pattern);
+          cairo_scale (cr, 1.0 / 20, 1.0 / 20);
+
+          cairo_rectangle (cr, x, y, width, height);
           cairo_fill (cr);
 
           cairo_pattern_destroy (pattern);
@@ -615,16 +552,14 @@ render_switch_lines (GtkThemingEngine *engine,
                      GtkOrientation orientation)
 {
   GtkStateFlags state;
-  GdkRGBA *lines_color;
+  GdkRGBA lines_color;
 
   state = gtk_theming_engine_get_state (engine);
 
   if (state & GTK_STATE_FLAG_INSENSITIVE)
     return;
 
-  gtk_theming_engine_get (engine, state,
-                          "-adwaita-switch-grip-color", &lines_color,
-                          NULL);
+  gtk_theming_engine_get_color (engine, state, &lines_color);
 
   cairo_save (cr);
 
@@ -642,12 +577,10 @@ render_switch_lines (GtkThemingEngine *engine,
   cairo_move_to (cr, 8.0, 0.0);
   cairo_line_to (cr, 8.0, 6.0);
 
-  gdk_cairo_set_source_rgba (cr, lines_color);
+  gdk_cairo_set_source_rgba (cr, &lines_color);
   cairo_stroke (cr);
 
   cairo_restore (cr);
-
-  gdk_rgba_free (lines_color);
 }
 
 static void
@@ -799,50 +732,6 @@ adwaita_engine_render_handle (GtkThemingEngine *engine,
     }
 }
 
-static void
-adwaita_engine_render_line (GtkThemingEngine *engine,
-                            cairo_t *cr,
-                            gdouble x0,
-                            gdouble y0,
-                            gdouble x1,
-                            gdouble y1)
-{
-  const GtkWidgetPath *path;
-
-  path = gtk_theming_engine_get_path (engine);
-
-  if ((gtk_theming_engine_has_class (engine, GTK_STYLE_CLASS_MARK) &&
-       gtk_widget_path_is_type (path, GTK_TYPE_SCALE)) ||
-      (gtk_theming_engine_has_class (engine, GTK_STYLE_CLASS_SEPARATOR) &&
-       gtk_widget_path_is_type (path, GTK_TYPE_TREE_VIEW)))
-    {
-      GtkStateFlags state;
-      GdkRGBA bg;
-
-      state = gtk_theming_engine_get_state (engine);
-      gtk_theming_engine_get_background_color (engine, state, &bg);
-
-      cairo_save (cr);
-
-      cairo_set_line_cap (cr, CAIRO_LINE_CAP_SQUARE);
-      cairo_set_line_width (cr, 1);
-
-      cairo_move_to (cr, x0 + 0.5, y0 + 0.5);
-      cairo_line_to (cr, x1 + 0.5, y1 + 0.5);
-
-      gdk_cairo_set_source_rgba (cr, &bg);
-      cairo_stroke (cr);
-
-      cairo_restore (cr);
-    }
-  else
-    {
-      GTK_THEMING_ENGINE_CLASS (adwaita_engine_parent_class)->render_line
-        (engine, cr,
-         x0, y0, x1, y1);
-    }
-}
-
 static void
 adwaita_engine_class_init (AdwaitaEngineClass *klass)
 {
@@ -850,8 +739,6 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
 
   engine_class->render_arrow = adwaita_engine_render_arrow;
   engine_class->render_focus = adwaita_engine_render_focus;
-  engine_class->render_check = adwaita_engine_render_check;
-  engine_class->render_option = adwaita_engine_render_option;
   engine_class->render_extension = adwaita_engine_render_extension;
   engine_class->render_frame = adwaita_engine_render_frame;
   engine_class->render_background = adwaita_engine_render_background;
@@ -859,7 +746,6 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
   engine_class->render_activity = adwaita_engine_render_activity;
   engine_class->render_slider = adwaita_engine_render_slider;
   engine_class->render_handle = adwaita_engine_render_handle;
-  engine_class->render_line = adwaita_engine_render_line;
 
   gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
                                         g_param_spec_boxed ("focus-border-color",
@@ -872,16 +758,6 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
                                                           "Focus border radius",
                                                           0, G_MAXINT, 0,
                                                           0));
-  gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
-                                        g_param_spec_boxed ("focus-border-gradient",
-                                                            "Focus border gradient",
-                                                            "Focus border gradient",
-                                                            CAIRO_GOBJECT_TYPE_PATTERN, 0));
-  gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
-                                        g_param_spec_boxed ("focus-fill-color",
-                                                            "Focus fill color",
-                                                            "Focus fill color",
-                                                            GDK_TYPE_RGBA, 0));
   gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
                                         g_param_spec_boxed ("selected-tab-color",
                                                             "Selected tab color",
@@ -897,16 +773,6 @@ adwaita_engine_class_init (AdwaitaEngineClass *klass)
                                                               "Focus border uses dashes",
                                                               "Focus border uses dashes",
                                                               FALSE, 0));
-  gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
-                                        g_param_spec_boxed ("menuitem-arrow-color",
-                                                            "Menuitem arrow color",
-                                                            "Menuitem arrow color",
-                                                            GDK_TYPE_RGBA, 0));
-  gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
-                                        g_param_spec_boxed ("switch-grip-color",
-                                                            "Switch grip color",
-                                                            "Switch grip color",
-                                                            GDK_TYPE_RGBA, 0));
   gtk_theming_engine_register_property (ADWAITA_NAMESPACE, NULL,
                                         g_param_spec_boxed ("progressbar-pattern",
                                                             "Progressbar pattern",
